# ArgparseCfg

Config for argparse.

WIP  

Simple wrapper for python argparse.  
Use dataclass for you app config.  
It gives you typed config instead of default Namespace from argparse.

You can see examples at `examples` folder - Same examples as ad python docs and tutorial for argparse.  

